@@ -219,7 +219,7 @@ class CloudPods:
             cpu: int = 256,
             mem: int = 1048576,
             storage_conf: str = "none",
-            storage_drive: str = "AdaptecRaid",
+            storage_driver: str = "AdaptecRaid",
             storage_count: int = 1,
             storage_adapter: int = 1,
             storage_type: str = "ssd"
@@ -305,7 +305,7 @@ class CloudPods:
             # 存储配置
             server_config["baremetal_disk_configs"] = [{
                 "conf": storage_conf,
-                "driver": storage_drive,
+                "driver": storage_driver,
                 "count": storage_count,
                 "range": list(range(0, storage_count)),  # 存储设备范围
                 "adapter": storage_adapter,
